==> zio-aws-memorydb_2.12-5.17.123.2-sources.jar: zio/aws/memorydb/model/AvailabilityZone.scala <==
package zio.aws.memorydb.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class AvailabilityZone(name: Option[String] = None) {
  def buildAwsValue()
      : software.amazon.awssdk.services.memorydb.model.AvailabilityZone = {
    import AvailabilityZone.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.memorydb.model.AvailabilityZone
      .builder()
      .optionallyWith(name.map(value => value: java.lang.String))(_.name)
      .build()
  }
  def asReadOnly: zio.aws.memorydb.model.AvailabilityZone.ReadOnly =
    zio.aws.memorydb.model.AvailabilityZone.wrap(buildAwsValue())
}
object AvailabilityZone {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.memorydb.model.AvailabilityZone
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.memorydb.model.AvailabilityZone =
      zio.aws.memorydb.model.AvailabilityZone(name.map(value => value))
    def name: Option[String]
    def getName: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("name", name)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.memorydb.model.AvailabilityZone
  ) extends zio.aws.memorydb.model.AvailabilityZone.ReadOnly {
    override val name: Option[String] =
      scala.Option(impl.name()).map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.memorydb.model.AvailabilityZone
  ): zio.aws.memorydb.model.AvailabilityZone.ReadOnly = new Wrapper(impl)
}

==> zio-aws-memorydb_2.12-5.17.166.1-sources.jar: zio/aws/memorydb/model/AvailabilityZone.scala <==
package zio.aws.memorydb.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class AvailabilityZone(name: Optional[String] = Optional.Absent) {
  def buildAwsValue()
      : software.amazon.awssdk.services.memorydb.model.AvailabilityZone = {
    import AvailabilityZone.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.memorydb.model.AvailabilityZone
      .builder()
      .optionallyWith(name.map(value => value: java.lang.String))(_.name)
      .build()
  }
  def asReadOnly: zio.aws.memorydb.model.AvailabilityZone.ReadOnly =
    zio.aws.memorydb.model.AvailabilityZone.wrap(buildAwsValue())
}
object AvailabilityZone {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.memorydb.model.AvailabilityZone
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.memorydb.model.AvailabilityZone =
      zio.aws.memorydb.model.AvailabilityZone(name.map(value => value))
    def name: Optional[String]
    def getName: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("name", name)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.memorydb.model.AvailabilityZone
  ) extends zio.aws.memorydb.model.AvailabilityZone.ReadOnly {
    override val name: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.name())
      .map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.memorydb.model.AvailabilityZone
  ): zio.aws.memorydb.model.AvailabilityZone.ReadOnly = new Wrapper(impl)
}
